#ifndef __NJB__BASE__H
#define __NJB__BASE__H

#include "libnjb.h"

int njb_discover (njb_t *njbs, int limit, int *errorflag);
void njb_device_dump (njb_t *njb, FILE *fp);
int njb_open (njb_t *njb);
void njb_close (njb_t *njb);
void njb_set_debug (int flags);
int njb_debug (int flag);

#endif

